select distinct sequence_owner
from   all_sequences
order by sequence_owner
